## What changed and why

## Testing

- [ ] `uv run pytest tests/ -v` passes
- [ ] `uv run ruff check .` clean
- [ ] `uv run mypy inspect_mlflow/` clean
- [ ] New tests added for new functionality

## Checklist

- [ ] Read [CONTRIBUTING.md](CONTRIBUTING.md)
- [ ] Pre-commit hooks pass (`uv run pre-commit run --all-files`)
- [ ] No breaking changes (or documented in description)
